@@ -8,10 +8,12 @@ from regolith.builder import builder
 from regolith.emailer import emailer as email
 from regolith.deploy import deploy as dploy
 
-
 RE_AND = re.compile('\s+and\s+')
 RE_SPACE = re.compile('\s+')
 
+INGEST_COLL_LU = {'.bib': 'citations'}
+
+
 def add_cmd(rc):
     """Adds documents to a collection in a database."""
     db = rc.client[rc.db]
@@ -23,26 +25,43 @@ def add_cmd(rc):
 
 def _ingest_citations(rc):
     import bibtexparser
+    from bibtexparser.bparser import BibTexParser
+    from bibtexparser.customization import getnames
+
+    parser = BibTexParser()
+    parser.ignore_nonstandard_types = False
+
+    def customizations(record):
+        for n in ['author', 'editor']:
+            if n in record:
+                a = [i for i in record[n].replace('\n', ' ').split(', ')]
+                b = [i.split(" and ") for i in a]
+                c = [item for sublist in b for item in sublist]
+                d = [i.strip() for i in c]
+                record[n] = getnames(d)
+
+        return record
+
+    parser.customization = customizations
     with open(rc.filename, 'r') as f:
-        bibs = bibtexparser.load(f)
+        bibs = bibtexparser.load(f, parser=parser)
     coll = rc.client[rc.db][rc.coll]
     for bib in bibs.entries:
         bibid = bib.pop('ID')
         bib['entrytype'] = bib.pop('ENTRYTYPE')
         if 'author' in bib:
-            bib['author'] = [a.strip() for a in RE_AND.split(bib['author'])]
+            bib['author'] = [a.strip() for b in bib['author'] for a in
+                             RE_AND.split(b)]
         if 'title' in bib:
             bib['title'] = RE_SPACE.sub(' ', bib['title'])
         rc.client.update_one(rc.db, rc.coll, {'_id': bibid},
-                             {'$set': bib}, upsert=True)
+                             bib, upsert=True)
 
 
 def _determine_ingest_coll(rc):
     f = rc.filename
     base, ext = os.path.splitext(f)
-    if ext == '.bib':
-        return 'citations'
-    return base
+    return INGEST_COLL_LU.get(ext, base)
 
 
 def ingest(rc):
@@ -52,7 +71,9 @@ def ingest(rc):
     if rc.coll == 'citations':
         _ingest_citations(rc)
     else:
-        raise ValueError("don't know how to ingest collection {0!r}".format(rc.coll))
+        raise ValueError(
+            "don't know how to ingest collection {0!r}".format(rc.coll))
+
 
 def _run_app(app, rc):
     if hasattr(app, 'rc'):
