@@ -1,11 +1,14 @@
 """Builder for Grade Reports."""
 import os
+import sys
+import pdb
 import shutil
+import traceback
 import subprocess
 from glob import glob
 from itertools import groupby
 
-from jinja2 import Environment, FileSystemLoader
+from jinja2 import Environment, FileSystemLoader, StrictUndefined
 try:
     from bibtexparser.bwriter import BibTexWriter
     from bibtexparser.bibdatabase import BibDatabase
@@ -44,7 +47,8 @@ class GradeReportBuilder(object):
         self.env = Environment(loader=FileSystemLoader([
                     'templates',
                     os.path.join(os.path.dirname(__file__), 'templates'),
-                    ]))
+                    ]),
+                    )
         self.construct_global_ctx()
         if HAVE_BIBTEX_PARSER:
             self.bibdb = BibDatabase()
@@ -86,7 +90,12 @@ class GradeReportBuilder(object):
         ctx['static'] = ctx.get('static',
                                os.path.relpath('static', os.path.dirname(fname)))
         ctx['root'] = ctx.get('root', os.path.relpath('/', os.path.dirname(fname)))
-        result = template.render(ctx)
+        try:
+            result = template.render(ctx)
+        except:
+            type, value, tb = sys.exc_info()
+            traceback.print_exc()
+            pdb.post_mortem(tb)
         with open(os.path.join(self.bldir, fname), 'wt') as f:
             f.write(result)
 
@@ -214,7 +223,7 @@ class GradeReportBuilder(object):
             if assignment_id not in stats:
                 n = len(assignment['points'])
                 z = (0,) * n
-                stats[assignment_id] = (z, z, 0, 0)
+                stats[assignment_id] = (z, z, z, z, z, 0, 0, 0, 0, 0)
         return stats
 
     @staticmethod
@@ -263,15 +272,15 @@ class GradeReportBuilder(object):
             raws.append(skw['student_letter_grade_raw'])
             curveds.append(skw['student_letter_grade_curved'])
         n = len(raws)
-        rfreq = [raws.count(l)/n for l in bins]
-        cfreq = [curveds.count(l)/n for l in bins]
+        rfreq = [raws.count(l) for l in bins]
+        cfreq = [curveds.count(l) for l in bins]
         width = 1.0
         pos = np.arange(len(bins))
         f, (ax1, ax2) = plt.subplots(1, 2, sharey=True)
         ax1.set_xticks(pos + (width / 2))
         ax1.set_xticklabels(bins)
         ax1.set_xlabel('Raw Grade')
-        ax1.set_ylabel('Fraction of Class')
+        ax1.set_ylabel('Number of Students')
         ax1.bar(pos, rfreq, width, color='yellow')
         ax1.grid(True)
         ax2.set_xticks(pos + (width / 2))
