@@ -2,13 +2,15 @@
 from __future__ import print_function
 import os
 import json
-from argparse import ArgumentParser
+from argparse import ArgumentParser, RawTextHelpFormatter
 
+from regolith.commands import INGEST_COLL_LU
 from regolith.runcontrol import RunControl, NotSpecified
 from regolith.validators import DEFAULT_VALIDATORS
 from regolith.database import connect
 from regolith import commands
 from regolith import storage
+from regolith.builder import BUILDERS
 
 DEFAULT_RC = RunControl(
     _validators=DEFAULT_VALIDATORS,
@@ -54,23 +56,30 @@ def load_rcfile(fname):
 def create_parser():
     p = ArgumentParser()
     subp = p.add_subparsers(title='cmd', dest='cmd')
+
     # rc subparser
     rcp = subp.add_parser('rc', help='prints run control')
+
     # add subparser
-    addp = subp.add_parser('add', help='adds a record to a database and collection')
+    addp = subp.add_parser('add',
+                           help='adds a record to a database and collection')
     addp.add_argument('db', help='database name')
     addp.add_argument('coll', help='collection name')
     addp.add_argument('documents', nargs='+', help='documents, in JSON / mongodb format')
+
     # ingest subparser
     ingp = subp.add_parser('ingest', help='ingest many records from a foreign '
                                           'resource into a database')
     ingp.add_argument('db', help='database name')
-    ingp.add_argument('filename', help='file to ingest')
+    ingp.add_argument('filename',
+                      help='file to ingest. Currently valid formats are: \n{}'
+                           ''.format([k for k in INGEST_COLL_LU]))
     ingp.add_argument('--coll', dest='coll',  default=None,
                       help='collection name, if this is not given it is infered from the '
                            'file type or file name.')
+
     # store subparser
-    strp = subp.add_parser('store', help='stores a file into the approriate '
+    strp = subp.add_parser('store', help='stores a file into the appropriate '
                                          'storage location.')
     strp.add_argument('storename', help='storage name')
     strp.add_argument('documents', nargs='+', help='paths to documents, i.e. '
@@ -79,21 +88,29 @@ def create_parser():
                       action='store_true',
                       help='forces copy of file if one of the same name '
                            'already exists')
+
     # app subparser
     appp = subp.add_parser('app', help='starts up a flask app for inspecting and '
                                        'modifying regolith data.')
     appp.add_argument('--debug', dest='debug', action='store_true', default=False,
                       help='starts server in debug mode')
+
     # grade subparser
     grdp = subp.add_parser('grade', help='starts up a flask app for adding '
                                          'grades to the database.')
     grdp.add_argument('--debug', dest='debug', action='store_true',
                       default=False, help='starts server in debug mode')
+
     # builder subparser
-    bldp = subp.add_parser('build', help='builds various available targets')
-    bldp.add_argument('build_targets', nargs='+', help='targets to build.')
+    bldp = subp.add_parser('build', help='builds various available targets',
+                           formatter_class=RawTextHelpFormatter)
+    bldp.add_argument('build_targets', nargs='+',
+                      help='targets to build. Currently valid targets are: \n{}'.
+                      format([k for k in BUILDERS]))
+
     # deploy subparser
     depp = subp.add_parser('deploy', help='deploys what was built by regolith')
+
     # email subparser
     emlp = subp.add_parser('email', help='automates emailing')
     emlp.add_argument('email_target', help='targets to email, eg "test" or '
@@ -109,6 +126,7 @@ def create_parser():
     emlp.add_argument('-c', '--course-id', dest='course_id', default=None,
                       help='course identifier that should be emailed.')
     emlp.add_argument('--db', help='database name', dest='db', default=None)
+
     # classlist subparser
     clp = subp.add_parser('classlist', help='updates classlist information from file')
     clp.add_argument('op', help='operatation to perform, such as "add" or "replace".')
